#
# spec file for package wasistlos
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wasistlos
Version:        1.7.0~20241019.b483456
Release:        bp160.1.11
Summary:        WhatsApp for Linux
License:        GPL-3.0-only
URL:            https://github.com/xeco23/WasIstLos
Source0:        WasIstLos-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ayatana-appindicator3-0.1)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(webkit2gtk-4.1)
Provides:       whatsapp-for-linux = %{version}
Obsoletes:      whatsapp-for-linux < %{version}
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++
%endif

%description
An unofficial WhatsApp desktop application written in C++.
Previously named whatsapp-for-linux.

%lang_package

%prep
%setup -q -n WasIstLos-%{version}

%build
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
export CXX="g++-11"
%endif

%cmake
%cmake_build

%install
%cmake_install
%fdupes -s %{buildroot}%{_datadir}/icons
rm  %{buildroot}%{_datadir}/locale/zh_Hans/LC_MESSAGES/wasistlos.mo

%find_lang %{name}

%files
%{_bindir}/%{name}
%{_datadir}/applications/com.github.xeco23.WasIstLos.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/*/status/*.png
%{_datadir}/metainfo/*.xml
%doc README.md
%license LICENSE

%files lang -f %{name}.lang

%changelog
* Sat Oct 19 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.7.0 and rename from whatsapp-for-linux to WasIstLos
  * Rename to WasIstLos #399
  * Add Ukrainian translation #406
  * Unknown locale code pt-br and zh-Hans #403
  * Update of czech translation #395
* Thu Apr 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.6.5:
  Implemented enhancements:
  * Add Chinese (simplified) translations #346
  * Port to WebKit2GTK 4.1 #302
  * Custom css or userscript #208
  Fixed bugs:
  * Google chrome version too old #360
  * Visual: Repo's readme could look better #357
  Merged pull requests:
  * Adding custom.css #370
  * Set user agent to a valid Google Chrome release #361
  * Update es.po #354
  * add polish translation #327
* Tue Jan 30 2024 Fridrich Strba <fstrba@suse.com>
- Update to recent git checkout that will eventually become 1.6.5
  * change dependency from pkgconfig(webkit2gtk-4.0) to
    pkgconfig(webkit2gtk-4.1)
* Tue Aug  8 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.6.4:
  Implemented enhancements:
  * Open the app in-window if a tray process already exists #323
  Fixed bugs:
  * Preferences are not saved when the app is closed to tray #325
  * Unintuitive behavior with both "start in tray" + "close
    to tray" enabled, especially for GNOME #320
  * WhatsApp Notification Sound Playing Continously #308
  * Ubuntu 22.04.1 / Wayland / DEB Not saving settings #244
  Closed issues:
  * chrome extension #322
  * App so slow on fedora linux #319
* Mon May 29 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.6.3:
  * Implemented enhancements:
    + Add german translations
    + Add czech translations (very incomplete)
    + Add hungarian translations
  * Fixed bugs:
    + Exit shortly after starting #289
    + Error message when opening Whatsapp app for Linux #282
  * Merged pull requests:
    + Update es.po #293
    + Explicitly specify Canberra dependency #283
* Sun Apr  2 2023 Carsten Ziepke <kieltux@gmail.com>
- Use gcc11-c++ for openSUSE Leap 15.5, fix "whatsapp-for-linux"
  requires the language dialect "CXX20"
* Sat Apr  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.6.2:
  * Workaround for audio messages #91
  * Add french #281
* Sat Feb 25 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.6.1:
  * Implemented enhancements:
    + Implement Ctrl+/- and Ctrl+scroll Zoom In/Out shortcuts #276
    + WhatsApp Web: Pass [ALT] key as [CMD] #280
* Sat Feb  4 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.6.0:
  * Implemented enhancements:
    + Notification sound #173
  * Fixed bugs:
    + "GLIBC_2.34 not found" appeared when trying to run the program
    .deb installed OK #273
    + Snap version displays unreadable/misplaced fonts in KDE Plasma
    running wayland #230
* Sun Jan 29 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.5.3:
  * "GLIBC_2.34 not found" when trying to run the program #273
* Mon Jan 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.5.2:
  * Implemented enhancements:
    + Find Russian translation and icons here #260
    + How can I remove it from the system? #248
  * Fixed bugs:
    + Unable to Paste Clipboard Images in Whatsapp for Linus #268
    + Use different compression mode for deb package #267
    + Dark theme not appearing for window border in Linux Mint
    21 Vanessa, Flatpak. #262
* Mon Dec 26 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.5.1:
  * Implemented enhancements:
    + Introduce Prefer Dark Theme #256
  * Fixed bugs:
    + Mic not enabled #252
    + Flatpak and Nvidia 520.65.01 driver compatibility #227
  * Closed issues:
    + High CPU usage when the focus is on the main window #115
  * Merged pull requests:
    + Updated Dutch translation #258
    + Update Italian translation #257
    + Add Mageia Linux to README.md #247
    + Add Russian translation (ru.po + desktop.in) #246
* Sat Oct 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.5.0:
  * Implemented enhancements:
    + Ctrl+P to open preferences #237
    + Localize WFL_FRIENDLY_NAME and WFL_DESCRIPTION for the desktop file #235
    + Simplify Config & Preferences (Breaks Backward Compatibility!) #229
    + Localization #180
    + Start minimised #136
  * Fixed bugs:
    + Preferences window is not attached to the main window #236
    + Permission issues #226
    + Slow responding even without hardware acceleration #225
    + Keeps freezing/spinning the CPU #224
    + WhatsApp For Linux starts but doesnt load, keeps in loading screen forever. #223
    + No Display with Whatsapp business account #220
    + Does not work with hardware acceleration + does not persist preferences #216
    + Spell check does not work #215
    + Flatpak version not running in Arch Linux #211
    + No Internet Connection Pop-up #209
    + Notification icon dissapears imediately #202
    + Auto turn off notifications #194
  * Merged pull requests:
    + Use official ArchLinux logo image in README #241
    + Update Italian translation #240
    + Add Italian translation #234
    + Added Dutch translation #233
    + Implement localization support #232
    + Implement start minimized option #231
    + Use webkit2gtk-4.1 if webkit2gtk-4.0 is not found #228
* Wed Oct 19 2022 Michael Vetter <mvetter@suse.com>
- Remove deprecated %%icon_theme_cache_post macros
* Tue Sep 27 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.4.7:
  * Fixed bugs:
    + Permission issues #226
    + WhatsApp For Linux starts but doesnt load, keeps in loading
    screen forever. #223
* Sat Aug  6 2022 Fridrich Strba <fstrba@suse.com>
- Update to 1.4.6
  * Fixed bugs:
    + Flatpak version not running in Arch Linux #211
* Thu Jul 21 2022 Fridrich Strba <fstrba@suse.com>
- Update to 1.4.5
  * Fixed bugs:
    + "GDBus.Error:org.freedesktop.portal.Error.NotAllowed: This
    call is not available inside the sandbox" #207
    + Incorrect display of the icon of the running application. #185
* Fri Jul  1 2022 Fridrich Strba <fstrba@suse.com>
- Initial packaging of WhatsApp for Linux unofficial client 1.4.4
